
## 0.1.2 (2023-12-18)

* add python 3.12 support (author @mentaljam, https://github.com/vincentsarago/color-operations/pull/5)

## 0.1.1 (2023-04-05)

* remove `.c` file from package
* switch linting to `ruff` and update pre-commit configuration

## 0.1.0 (2022-11-09)

* Initial release. Match rio-color 1.0.4 https://github.com/mapbox/rio-color/releases/tag/1.0.4
